@@ -42,6 +42,7 @@ def run(
     max_width: int,
     glob_pers_min: float,
     constrain_heights: bool,
+    k: int,
     loc_pers_min: float,
     loc_trend_min: float,
     force: bool,
@@ -53,18 +54,35 @@ def run(
     log_file: Optional[pathlib.Path] = None,
     plot_dir: Optional[pathlib.Path] = None,
     normalization: Optional[str] = None,
+    telem_span=None,
 ) -> int:
     """
     Entrypoint for stripepy call
     """
     args = locals()
-    args.pop("main_logger")
+    for a in ("main_logger", "telem_span"):
+        args.pop(a)
 
     start_global_time = time.time()
 
     parent_logger = main_logger
     main_logger = structlog.get_logger().bind(step="main")
 
+    _configure_telemetry(
+        telem_span,
+        contact_map=contact_map,
+        resolution=resolution,
+        genomic_belt=genomic_belt,
+        max_width=max_width,
+        glob_pers_min=glob_pers_min,
+        constrain_heights=constrain_heights,
+        k=k,
+        loc_pers_min=loc_pers_min,
+        loc_trend_min=loc_trend_min,
+        nproc=nproc,
+        normalization=normalization,
+    )
+
     _write_param_summary(args, logger=main_logger)
 
     if roi is not None:
@@ -96,6 +114,7 @@ def run(
                     constrain_heights=constrain_heights,
                     genomic_belt=genomic_belt,
                     glob_pers_min=glob_pers_min,
+                    k=k,
                     loc_pers_min=loc_pers_min,
                     loc_trend_min=loc_trend_min,
                     max_width=max_width,
@@ -236,6 +255,7 @@ def run(
                 result=result,
                 lt_matrix=lt_matrix,
                 ut_matrix=ut_matrix,
+                k=k,
                 tpool=tpool,
                 pool=pool,
                 logger=logger,
@@ -286,10 +306,66 @@ def run(
     return 0
 
 
+def _infer_matrix_format(path: pathlib.Path) -> str:
+    import hictkpy
+
+    if hictkpy.is_hic(path):
+        return "hic"
+
+    if hictkpy.is_cooler(path):
+        return "cool"
+
+    if hictkpy.is_mcool_file(path):
+        return "mcool"
+
+    if hictkpy.is_scool_file(path):
+        return "scool"
+
+    return "unknown"
+
+
+def _configure_telemetry(
+    span,
+    contact_map: pathlib.Path,
+    resolution: int,
+    genomic_belt: int,
+    max_width: int,
+    glob_pers_min: float,
+    constrain_heights: bool,
+    k: int,
+    loc_pers_min: float,
+    loc_trend_min: float,
+    nproc: int,
+    normalization: Optional[str] = None,
+):
+    try:
+        if not span.is_recording():
+            return
+
+        span.set_attributes(
+            {
+                "params.contact_map_format": _infer_matrix_format(contact_map),
+                "params.contact_map_resolution": resolution,
+                "params.contact_map_raw_interactions": normalization is None,
+                "params.genomic_belt": genomic_belt,
+                "params.max_width": max_width,
+                "params.glob_pers_min": glob_pers_min,
+                "params.constrain_heights": constrain_heights,
+                "params.k": k,
+                "params.loc_pers_min": loc_pers_min,
+                "params.loc_trend_min": loc_trend_min,
+                "params.nproc": nproc,
+            }
+        )
+    except:  # noqa
+        pass
+
+
 def _generate_metadata_attribute(
     constrain_heights: bool,
     genomic_belt: int,
     glob_pers_min: float,
+    k: int,
     loc_pers_min: float,
     loc_trend_min: float,
     max_width: int,
@@ -302,6 +378,7 @@ def _generate_metadata_attribute(
         "constrain-heights": constrain_heights,
         "genomic-belt": genomic_belt,
         "global-persistence-minimum": glob_pers_min,
+        "k-neighbour": k,
         "local-persistence-minimum": loc_pers_min,
         "local-trend-minimum": loc_trend_min,
         "max-width": max_width,
@@ -570,6 +647,7 @@ def _run_step_4(
     result: Result,
     lt_matrix: Optional[SparseMatrix],
     ut_matrix: Optional[SparseMatrix],
+    k: int,
     tpool: Union[ProcessPoolWrapper, concurrent.futures.ThreadPoolExecutor],
     pool: ProcessPoolWrapper,
     logger,
@@ -590,8 +668,8 @@ def _run_step_4(
         executor = pool.map
 
     params = (
-        (result.get("stripes", "lower"), lt_matrix, "lower", executor, logger),
-        (result.get("stripes", "upper"), ut_matrix, "upper", executor, logger),
+        (result.get("stripes", "lower"), lt_matrix, "lower", k, executor, logger),
+        (result.get("stripes", "upper"), ut_matrix, "upper", k, executor, logger),
     )
 
     (_, lt_stripes), (_, ut_stripes) = list(tpool.map(_run_step_4_helper, params))
